"""
Moonito - Bot Protection, Traffic Filtering, and Web Analytics for Python
"""

from .visitor_traffic_filtering import VisitorTrafficFiltering, Config

__version__ = "1.0.0"
__all__ = ["VisitorTrafficFiltering", "Config"]